package Alien::Nettle;

use strict;
use warnings;
use base qw( Alien::Base2 );

# ABSTRACT: Find or build nettle low-level cryptographic library
our $VERSION = '0.01'; # VERSION

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Alien::Nettle - Find or build nettle low-level cryptographic library

=head1 VERSION

version 0.01

=head1 AUTHOR

Graham Ollis <plicease@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Graham Ollis.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
